"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getCloudinaryParams = getCloudinaryParams;
exports.default = getCloudinaryLink;

var _interpolate = _interopRequireDefault(require("interpolate"));

var _config = require("../config");

var _getImageSize = _interopRequireDefault(require("./getImageSize"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/* eslint-disable camelcase */
function getCloudinaryParams(size) {
  if (!size) return [];
  var width = size.width,
      height = size.height;
  return ['c_scale', 'q_auto', width && "w_".concat(width), height && "h_".concat(height)].filter(function (x) {
    return x;
  });
}

function getCloudinaryLink(_ref) {
  var username = _ref.username,
      id = _ref.id,
      public_id = _ref.public_id,
      boxSize = _ref.boxSize,
      autoScale = _ref.autoScale,
      useMinimum = _ref.useMinimum;
  var template = 'https://res.cloudinary.com/{username}/image/upload/{transform}{id}';
  var size = (0, _getImageSize.default)({
    boxSize: boxSize,
    autoScale: autoScale,
    useMinimum: useMinimum
  });
  var params = getCloudinaryParams(size);
  var transform = params.length > 0 ? "".concat(params.join(','), "/") : '';
  return (0, _interpolate.default)(template, {
    username: username || (0, _config.getCloudinaryUsername)(),
    id: id || public_id,
    transform: transform
  });
}