/* eslint-disable camelcase */

// @flow

import React from 'react'
import interpolate from 'interpolate'
import { getCloudinaryUsername } from 'config'

const template =
  '//res.cloudinary.com/{cloud}/image/upload{transform}/{public_id}'

const defaultSteps = [
  { vw: 400, w: 400 },
  { vw: 600, w: 600 },
  { vw: 800, w: 800 },
  { vw: 1000, w: 1000 },
  { vw: 1200, w: 1200 },
]

function makeSrcset({
  cloud = getCloudinaryUsername(),
  steps,
  quality,
  public_id,
}: {
  cloud?: string,
  steps: { vw: number, w: number }[],
  quality: number | 'auto',
  public_id: string,
}) {
  return steps.map(({ vw, w }) => {
    const size = vw
    const src = interpolate(template, {
      public_id,
      transform: `/w_${w},q_${quality}`,
      cloud,
    })
    return { src, size }
  })
}

type Props = {
  image: {
    public_id: string,
  },
  cloud?: string,
  quality: number | 'auto',
  steps: { vw: number, w: number }[],
}

class CloudinaryImage extends React.PureComponent<Props, *> {
  original: string
  srcSet: string
  otherProps: any

  static defaultProps = {
    quality: 'auto',
    steps: defaultSteps,
  }

  /* Calculate in constructor because we don't want srcSet to re-render */
  constructor(props: *) {
    super(props)
    const { image, steps, cloud, quality, ...otherProps } = this.props

    this.otherProps = otherProps
    this.srcSet = makeSrcset({
      cloud,
      steps,
      quality,
      public_id: this.props.image.public_id,
    })
      .map(({ src, size }) => `${src} ${size}w`)
      .join(', ')

    this.original = interpolate(template, {
      public_id: this.props.image.public_id,
      transform: '',
      cloud,
    })
  }

  render() {
    const { alt, ...rest } = this.otherProps
    return <img {...rest} alt={alt} src={this.original} srcSet={this.srcSet} />
  }
}

export default CloudinaryImage
