// @flow

import React from 'react'
import { themr } from 'react-css-themr'
import { compose, withState } from 'recompose'
import Icon from 'components/Icon'
import { Collapse as BaseCollapse } from 'react-collapse'

function Collapse({
  icon,
  label,
  children,
  isOpened,
  openedIcon = 'fa-angle-up',
  closedIcon = 'fa-angle-down',
  hasNestedCollapse,
  open,
  theme,
}: {
  icon: string,
  label: string,
  children: any,
  isOpened?: boolean,
  openedIcon?: string,
  closedIcon?: string,
  hasNestedCollapse?: boolean,
  open?: (isOpened: boolean) => void,
  theme: TTheme,
}) {
  return (
    <div className={theme.root}>
      <div
        className={theme.header}
        onClick={() => {
          if (open) open(!isOpened)
        }}
      >
        <div className={theme.labelWrapper}>
          {icon && <Icon className={theme.icon} icon={icon} />}
          {label && <span className={theme.label}>{label}</span>}
        </div>
        <div className={theme.statusWrapper}>
          <Icon icon={isOpened ? openedIcon : closedIcon} />
        </div>
      </div>
      <BaseCollapse
        theme={{ collapse: theme.collapse, content: theme.content }}
        isOpened={isOpened}
        hasNestedCollapse={hasNestedCollapse}
      >
        {children}
      </BaseCollapse>
    </div>
  )
}

export default compose(
  withState('isOpened', 'open', props => props.isOpened),
  themr('Collapse', {}, { composeTheme: 'softly' }),
)(Collapse)
