// @flow

import React from 'react'
import { mount } from 'enzyme'
import Image from '../index'

const cloud = 'alice28'

describe('Image', () => {
  it('use src', () => {
    const src = 'https://source.unsplash.com/random/800x600'
    const wrapper = mount(
      <Image className="bg" src={src} alt="code" theme={{}} />,
    )
    const imgComponent = wrapper.find('img')
    expect(imgComponent.props().src).toEqual(src)
  })

  it('use src cloudinary', () => {
    const src =
      'https://res.cloudinary.com/alice28/image/upload/v1501418680/css-code_t7qmyu.jpg'
    const result =
      'https://res.cloudinary.com/alice28/image/upload/v1501418680/css-code_t7qmyu.jpg'
    const wrapper = mount(
      <Image className="bg" src={src} alt="code" theme={{}} />,
    )
    const imgComponent = wrapper.find('img')
    expect(imgComponent.props().src).toEqual(result)
  })

  it('use cloudinary image', () => {
    const expectedSrc =
      '//res.cloudinary.com/alice28/image/upload/css-code_t7qmyu.jpg'
    const expectedSrcSet =
      '//res.cloudinary.com/alice28/image/upload/w_400,q_auto/css-code_t7qmyu.jpg 400w, //res.cloudinary.com/alice28/image/upload/w_600,q_auto/css-code_t7qmyu.jpg 600w, //res.cloudinary.com/alice28/image/upload/w_800,q_auto/css-code_t7qmyu.jpg 800w, //res.cloudinary.com/alice28/image/upload/w_1000,q_auto/css-code_t7qmyu.jpg 1000w, //res.cloudinary.com/alice28/image/upload/w_1200,q_auto/css-code_t7qmyu.jpg 1200w'
    const image = {
      public_id: 'css-code_t7qmyu.jpg',
    }
    const wrapper = mount(
      <Image
        cloud={cloud}
        className="bg"
        image={image}
        alt="Some alt"
        title="Some title"
      />,
    )
    const imgComponent = wrapper.find('img')
    const { src, srcSet, alt, title } = imgComponent.props()
    expect(src).toEqual(expectedSrc)
    expect(srcSet).toEqual(expectedSrcSet)
    expect(alt).toEqual('Some alt')
    expect(title).toEqual('Some title')
  })
})
