/* eslint-disable camelcase */

// @flow

import React from 'react'
import interpolate from 'interpolate'
import { getCloudinaryUsername } from 'config'
import { template, imageFromId } from './cloudinary'

const defaultSteps = [
  { vw: 400, w: 400 },
  { vw: 600, w: 600 },
  { vw: 800, w: 800 },
  { vw: 1000, w: 1000 },
  { vw: 1200, w: 1200 },
]

function makeSrcset({
  cloud,
  steps,
  quality,
  public_id,
}: {
  cloud: string,
  steps: { vw: number, w: number }[],
  quality?: 'auto' | number,
  public_id: string,
}) {
  return steps.map(({ vw, w }) => {
    const size = vw
    const src = interpolate(template, {
      public_id,
      transform: `/w_${w},q_${quality || 'auto'}`,
      cloud,
    })
    return { src, size }
  })
}

export type ImageProps = {
  image?: {
    public_id: string,
  },
  cloud?: string,
  quality?: number | 'auto',
  steps: { vw: number, w: number }[],
  src?: string,
}

class Image extends React.PureComponent<ImageProps, *> {
  original: string
  srcSet: string
  otherProps: any

  static defaultProps = {
    quality: 'auto',
    steps: defaultSteps,
  }

  /* Calculate in constructor because we don't want srcSet to re-render */
  constructor(props: *) {
    super(props)
    const {
      image,
      src,
      steps,
      cloud = getCloudinaryUsername(),
      quality,
      ...otherProps
    } = this.props

    this.otherProps = otherProps
    if (!image) {
      if (!src) throw new Error('Image component require image or src')

      // TODO: Check if src is CloudinaryImage => parse it
      this.original = src
      return
    }

    this.srcSet = makeSrcset({
      cloud,
      steps,
      quality,
      public_id: image.public_id,
    })
      .map(item => `${item.src} ${item.size}w`)
      .join(', ')

    this.original = imageFromId({ cloud, public_id: image.public_id })
  }

  render() {
    const { alt, ...rest } = this.otherProps
    return <img {...rest} alt={alt} src={this.original} srcSet={this.srcSet} />
  }
}

export default Image
