// @flow

import React, { PureComponent } from 'react'
import Lightbox from 'react-images'
import ImageItem from 'components/ImageItem'
import mergeTheme from 'helpers/mergeTheme'
import getImageLink from 'helpers/getImageLink'

type TImageGalleryState = {
  gallery: any[],
  opened: boolean,
  selected: number,
}

class ImageGallery extends PureComponent<TImageGallery, any> {
  state: TImageGalleryState
  constructor(props: any) {
    super(props)
    const { items } = props || {}
    const gallery = (items || []).map(({ image }) => {
      if (!image) return null
      const source = getImageLink({
        ...image,
        // boxSize: size,
        autoScale: true,
        usePlaceholder: true,
      })
      return { src: (source && source.large) || source }
    })
    this.state = {
      gallery,
      opened: false,
      selected: 0,
    }
  }
  render() {
    const { items, theme = {} } = this.props
    const { selected, opened, gallery } = this.state
    return (
      <div data-component="ImageGallery" className={theme.root}>
        {(items || []).map((item, idx) => (
          <div key={idx} className={theme.itemWrapper}>
            <ImageItem
              {...item}
              theme={mergeTheme(theme.item || {}, item.theme || {})}
              onClick={() => this.setState({ selected: idx, opened: true })}
            />
          </div>
        ))}
        <Lightbox
          currentImage={selected}
          images={gallery}
          isOpen={opened}
          onClickPrev={() => {
            this.setState({
              selected: selected - 1 < 0 ? selected : selected - 1,
            })
          }}
          onClickNext={() => {
            this.setState({
              selected: selected + 1 >= items.length ? 0 : selected + 1,
            })
          }}
          onClose={() => this.setState({ opened: false })}
        />
      </div>
    )
  }
}

export default ImageGallery
