// @flow

import React from 'react'
import { themr } from 'react-css-themr'
import Image, { type ImageProps } from 'components/Image'
import InfoItem, { type InfoItemProps } from 'components/InfoItem'

export type Props = {
  image: ImageProps,
  info: InfoItemProps,
  theme?: *,
}

function ImageItem({ image, info, theme = {}, ...props }: Props) {
  return (
    <div {...props} data-component="ImageItem" className={theme.root}>
      <div className={theme.imageWrapper}>
        <Image className={theme.image} {...image} />
      </div>
      <div className={theme.infoWrapper}>
        <InfoItem theme={theme.info} {...info} />
      </div>
    </div>
  )
}

export default themr('ImageItem', {}, { composeTheme: 'softly' })(ImageItem)
