// @flow

import React from 'react'
import Text from 'components/Text'
import IconItemList from 'components/IconItemList'
import KeyValueList from 'components/KeyValueList'

export type InfoItemProps = {
  title?: string,
  subtitle?: string,
  description?: string,
  iconItems?: TIconItem[],
  keyValueItems?: TKeyValueItem[],
  actions?: TAction[],
  theme?: TTheme,
}

function InfoItem({
  title,
  subtitle,
  description,
  iconItems,
  keyValueItems,
  theme = {},
}: InfoItemProps) {
  return (
    <div data-component="InfoItem" className={theme.root}>
      <div className={theme.contentWrapper}>
        {title && (
          <Text
            data-element="Title"
            className={theme.title}
            wrapperClassName={theme.titleWrapper}
          >
            {title}
          </Text>
        )}
        {subtitle && (
          <Text
            data-element="Subtitle"
            className={theme.subtitle}
            wrapperClassName={theme.subtitleWrapper}
          >
            {subtitle}
          </Text>
        )}
        {description && (
          <Text
            data-element="Description"
            className={theme.description}
            wrapperClassName={theme.descriptionWrapper}
          >
            {description}
          </Text>
        )}
      </div>
      {iconItems &&
        iconItems.length > 0 && (
          <IconItemList items={iconItems} theme={theme.iconItemList} />
        )}
      {keyValueItems &&
        keyValueItems.length > 0 && (
          <KeyValueList items={keyValueItems} theme={theme.keyValueList} />
        )}
    </div>
  )
}

export default InfoItem
