// @flow

import React from 'react'
import cn from 'classnames'
import { themr } from 'react-css-themr'
import Loader from 'components/Loader'
import BaseMap from './Map'

function Map({
  className,
  markers,
  center,
  source,
  options,
  theme = {},
  ...props
}: {
  className?: string,
  markers?: TCoords[],
  center: TCoords,
  source: string,
  options?: {
    zoom?: number,
  },
  theme: TTheme,
}) {
  return (
    <div data-component="Map" className={cn(className, theme.root)}>
      <BaseMap
        {...props}
        markers={markers}
        center={center}
        options={options}
        googleMapURL={source}
        loadingElement={<Loader className={theme.loader} />}
        containerElement={<div className={theme.container} />}
        mapElement={<div className={theme.content} />}
      />
    </div>
  )
}

export default themr('Map', {}, { composeTheme: 'softly' })(Map)
