// @flow

import React from 'react'
import { Motion, spring } from 'react-motion'
import { compose, withState } from 'recompose'
import { themr } from 'react-css-themr'
import throttle from 'lodash.throttle'
import EventListener from 'react-event-listener'
import Fragment from 'components/Fragment'

type NavProps = {
  showOnStart?: boolean,
  children?: any,
  showOn?: number, // Enter when scroll down
  hideOn?: number, // Hide on scroll down
  throttleInterval?: number,
  animation?: boolean,
  hideOnScrollDown?: boolean, // Hide on scroll down, so it only show when scroll up
  // Props from recompose
  isShow: ?boolean,
  show: (isShow: ?boolean) => void,
  theme: TTheme,
}

class Nav extends React.Component<NavProps, any> {
  static defaultProps = {
    showOnStart: true,
    animation: true,
  }
  previous = 0

  onScroll = () => {
    const { show, hideOn, showOn } = this.props
    if (hideOn) {
      // console.log({ show, hideOn, previous: this.previous }, window.scrollY)
      if (window.scrollY >= hideOn) {
        show(false)
      } else {
        show(true)
      }
    }
    if (showOn) {
      // console.log({ show, hideOn, previous: this.previous }, window.scrollY)
      if (window.scrollY >= showOn) {
        show(true)
      } else {
        show(false)
      }
    }

    this.previous = window.scrollY
  }

  render() {
    const { isShow, animation, theme, children } = this.props

    return (
      <Fragment>
        {animation && (
          <Motion
            defaultStyle={{
              top: -110,
            }}
            style={{
              top: isShow ? spring(0) : spring(-110),
            }}
          >
            {style => (
              <div
                data-component="Nav"
                className={theme.root}
                style={{
                  transform: `translateY(${style.top}px)`,
                }}
              >
                {children}
              </div>
            )}
          </Motion>
        )}
        {!animation &&
          isShow && (
            <div data-component="Nav" className={theme.root}>
              {children}
            </div>
          )}
        <EventListener
          target="window"
          onScroll={throttle(this.onScroll, 100)}
        />
      </Fragment>
    )
  }
}

export default compose(
  themr('Nav', {}, { composeTheme: 'softly' }),
  withState('isShow', 'show', ({ showOnStart = true }) => showOnStart),
)(Nav)
