// @flow

import React from 'react'

export type VideoProps = {
  controls?: boolean,
  sources: { type: string, src: string }[],
  tracks?: any[],
  theme?: TTheme,
}

export function Video({
  controls,
  sources = [],
  tracks = [],
  ...rest
}: VideoProps) {
  return (
    <video
      controls={controls}
      data-component="Video"
      {...rest}
    >
      {(sources || []).map(({ ...source }, idx) => (
        <source key={idx} {...source} />
      ))}
      {(tracks || []).map(({ ...track }, idx) => (
        <track key={idx} {...track} />
      ))}
    </video>
  )
}

Video.defaultProps = {
  controls: true,
  tracks: [],
}

export default Video
