// @flow

import React from 'react'
import Video, { type VideoProps } from 'components/Video'
import InfoItem from 'components/InfoItem'

export type Props = {
  video: VideoProps,
  iframe?: string,
  embed?: string,
  info: {},
  title?: string,
  subtitle?: string,
  description?: string,
  iconItems?: TIconItem[],
  keyValueItems?: TKeyValueItem[],
  actions?: TAction[],
  theme?: TTheme,
}

function VideoItem({
  iframe,
  embed,
  video,
  title,
  subtitle,
  description,
  iconItems,
  keyValueItems,
  actions,
  theme = {},
}: Props) {
  return (
    <div data-component="VideoItem" className={theme.root}>
      <div className={theme.videoWrapper}>
        {iframe && <iframe className={theme.video} src={iframe} />}
        {embed && <embed className={theme.video} src={embed} />}
        {video && <Video className={theme.video} {...video} />}
      </div>
      <div className={theme.infoItemWrapper}>
        <InfoItem
          title={title}
          subtitle={subtitle}
          description={description}
          iconItems={iconItems}
          keyValueItems={keyValueItems}
          actions={actions}
          theme={theme.infoItem}
        />
      </div>
    </div>
  )
}

export default VideoItem
