/* eslint-disable camelcase */

// @flow

import interpolate from 'interpolate'
import { getCloudinaryUsername } from 'config'
import getImageSize from './getImageSize'

export function getCloudinaryParams(size: ?TSize) {
  if (!size) return []
  const { width, height } = size
  return [
    'c_scale',
    'q_auto',
    width && `w_${width}`,
    height && `h_${height}`,
  ].filter(x => x)
}

export default function getCloudinaryLink({
  username,
  id,
  public_id,
  boxSize,
  autoScale,
  useMinimum,
}: {
  username: string,
  id?: string,
  public_id?: string,
  boxSize?: TSize,
  autoScale?: boolean,
  useMinimum?: boolean,
}) {
  const template =
    'https://res.cloudinary.com/{username}/image/upload/{transform}{id}'
  const size = getImageSize({ boxSize, autoScale, useMinimum })
  const params = getCloudinaryParams(size)
  const transform = params.length > 0 ? `${params.join(',')}/` : ''
  return interpolate(template, {
    username: username || getCloudinaryUsername(),
    id: id || public_id,
    transform,
  })
}
