// @flow

import { getPlaceholderImage } from 'config'
import getCloudinaryLink from './getCloudinaryLink'
import getCustomImageLink from './getCustomImageLink'

type TImageLink = string | { thumbnail: string, large: string }

export default function getImageLink({
  src,
  cloudinary,
  boxSize,
  useMinimum,
  autoScale = true,
  usePlaceholder = true,
}: TImageData): TImageLink {
  if (src) {
    return getCustomImageLink({ src, boxSize, useMinimum, autoScale }) || src
  }
  if (cloudinary) {
    const { username, id } = cloudinary
    return {
      thumbnail: getCloudinaryLink({
        username,
        id,
        boxSize,
        useMinimum: true,
        autoScale,
      }),
      large: getCloudinaryLink({
        username,
        id,
        boxSize,
        useMinimum: false,
        autoScale,
      }),
    }
  }
  if (usePlaceholder) return getPlaceholderImage({ boxSize })
  return ''
}
