// @flow

const steps = [50, 100, 200, 400, 800, 1200]
const lastStep = steps[steps.length - 1]

/*
 * Get actual image size. Return null mean it will use the original size
 */
export default function getImageSize({
  boxSize: _boxSize,
  useMinimum,
  autoScale = true,
}: {
  boxSize?: TSize,
  useMinimum?: boolean,
  autoScale?: boolean,
  }): ?TSize {
  let boxSize = _boxSize
  if (useMinimum) boxSize = { width: steps[0], height: steps[0] }

  if (!autoScale) return null
  if (!boxSize) return null

  const { width = 0, height = 0 } = boxSize

  // Do not calculate if width and height is not provided
  if ((!width && !height) || width + height === 0) return null

  if (width >= height) {
    return { width: steps.find(step => step >= width) || lastStep }
  }
  return { height: steps.find(step => step >= height) || lastStep }
}
